aboutsummaryrefslogtreecommitdiff
path: root/app/build.gradle
diff options
context:
space:
mode:
authorBryson Steck <steck.bryson@gmail.com>2021-05-04 17:59:55 -0600
committerBryson Steck <steck.bryson@gmail.com>2021-05-04 17:59:55 -0600
commit99643e5be84af7e8da217ed48597ceb3c9d3bc85 (patch)
tree91c314dc3a0f4b60d731ccb8854869302eb9bd8d /app/build.gradle
parentaf7a395b8c707fe5be3c03e9de878fae1d16b997 (diff)
downloadwiimmfi-watcher-99643e5be84af7e8da217ed48597ceb3c9d3bc85.tar
wiimmfi-watcher-99643e5be84af7e8da217ed48597ceb3c9d3bc85.tar.gz
wiimmfi-watcher-99643e5be84af7e8da217ed48597ceb3c9d3bc85.tar.bz2
before i get too deep in the database stuff
Diffstat (limited to 'app/build.gradle')
-rw-r--r--app/build.gradle66
1 files changed, 45 insertions, 21 deletions
diff --git a/app/build.gradle b/app/build.gradle
index ecfb534..37f338e 100644
--- a/app/build.gradle
+++ b/app/build.gradle
@@ -26,35 +26,59 @@ android {
sourceCompatibility JavaVersion.VERSION_1_8
targetCompatibility JavaVersion.VERSION_1_8
}
+ dataBinding {
+ enabled = true
+ }
}
+
dependencies {
- implementation "androidx.fragment:fragment:1.3.3"
- implementation 'androidx.appcompat:appcompat:1.2.0'
- implementation 'com.google.android.material:material:1.3.0'
- implementation 'androidx.constraintlayout:constraintlayout:2.0.4'
- implementation files('libs/jsoup-1.13.1.jar')
- implementation 'com.android.support:cardview-v7:28.0.0'
- testImplementation 'junit:junit:4.+'
- androidTestImplementation 'androidx.test.ext:junit:1.1.2'
- androidTestImplementation 'androidx.test.espresso:espresso-core:3.3.0'
dependencies {
- def room_version = "2.3.0"
+ dependencies {
+ def lifecycle_version = "2.3.1"
+ def arch_version = "2.1.0"
- implementation "androidx.room:room-runtime:$room_version"
- annotationProcessor "androidx.room:room-compiler:$room_version"
+ // ViewModel
+ implementation "androidx.lifecycle:lifecycle-viewmodel:$lifecycle_version"
+ // LiveData
+ implementation "androidx.lifecycle:lifecycle-livedata:$lifecycle_version"
+ }
+ def lifecycle_version = "2.3.1"
+ def arch_version = "2.1.0"
- // optional - RxJava2 support for Room
- implementation "androidx.room:room-rxjava2:$room_version"
+ // ViewModel
+ implementation "androidx.lifecycle:lifecycle-viewmodel:$lifecycle_version"
+ // LiveData
+ implementation "androidx.lifecycle:lifecycle-livedata:$lifecycle_version"
- // optional - RxJava3 support for Room
- implementation "androidx.room:room-rxjava3:$room_version"
+ implementation "androidx.fragment:fragment:1.3.3"
+ implementation 'androidx.appcompat:appcompat:1.2.0'
+ implementation 'com.google.android.material:material:1.3.0'
+ implementation 'androidx.constraintlayout:constraintlayout:2.0.4'
+ implementation files('libs/jsoup-1.13.1.jar')
+ implementation 'com.android.support:cardview-v7:28.0.0'
+ testImplementation 'junit:junit:4.+'
+ implementation "androidx.drawerlayout:drawerlayout:1.1.1"
+ androidTestImplementation 'androidx.test.ext:junit:1.1.2'
+ androidTestImplementation 'androidx.test.espresso:espresso-core:3.3.0'
+ dependencies {
+ def room_version = "2.3.0"
- // optional - Guava support for Room, including Optional and ListenableFuture
- implementation "androidx.room:room-guava:$room_version"
+ implementation "androidx.room:room-runtime:$room_version"
+ annotationProcessor "androidx.room:room-compiler:$room_version"
- // optional - Test helpers
- testImplementation "androidx.room:room-testing:$room_version"
- }
+ // optional - RxJava2 support for Room
+ implementation "androidx.room:room-rxjava2:$room_version"
+
+ // optional - RxJava3 support for Room
+ implementation "androidx.room:room-rxjava3:$room_version"
+ // optional - Guava support for Room, including Optional and ListenableFuture
+ implementation "androidx.room:room-guava:$room_version"
+
+ // optional - Test helpers
+ testImplementation "androidx.room:room-testing:$room_version"
+ }
+
+ }
} \ No newline at end of file